aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--engines/cge2/cge2.cpp6
-rw-r--r--engines/cge2/cge2.h8
-rw-r--r--engines/cge2/cge2_main.cpp22
-rw-r--r--engines/cge2/hero.h6
-rw-r--r--engines/cge2/snail.cpp8
5 files changed, 25 insertions, 25 deletions
diff --git a/engines/cge2/cge2.cpp b/engines/cge2/cge2.cpp
index 565615c9ed..135f786de0 100644
--- a/engines/cge2/cge2.cpp
+++ b/engines/cge2/cge2.cpp
@@ -54,7 +54,7 @@ CGE2Engine::CGE2Engine(OSystem *syst, const ADGameDescription *gameDescription)
for (int i = 0; i < 2; i++)
_heroTab[i] = nullptr;
_eye = nullptr;
- for (int i = 0; i < kCaveMax; i++)
+ for (int i = 0; i < kSceneMax; i++)
_eyeTab[i] = nullptr;
_spare = nullptr;
_commandHandler = nullptr;
@@ -108,7 +108,7 @@ void CGE2Engine::init() {
for (int i = 0; i < 2; i++)
_heroTab[i] = new HeroTab(this);
_eye = new V3D();
- for (int i = 0; i < kCaveMax; i++)
+ for (int i = 0; i < kSceneMax; i++)
_eyeTab[i] = new V3D();
_spare = new Spare(this);
_commandHandler = new CommandHandler(this, false);
@@ -133,7 +133,7 @@ void CGE2Engine::deinit() {
delete _text;
for (int i = 0; i < 2; i++)
delete _heroTab[i];
- for (int i = 0; i < kCaveMax; i++) {
+ for (int i = 0; i < kSceneMax; i++) {
delete _eyeTab[i];
}
delete _eye;
diff --git a/engines/cge2/cge2.h b/engines/cge2/cge2.h
index 0206a3ce6d..e19ca576d3 100644
--- a/engines/cge2/cge2.h
+++ b/engines/cge2/cge2.h
@@ -70,7 +70,7 @@ class Map;
#define kDimMax 8
#define kWayMax 10
#define kPocketMax 4
-#define kCaveMax 100
+#define kSceneMax 100
#define kMaxPoint 4
#define kInfoX 160
#define kInfoY -11
@@ -107,8 +107,8 @@ public:
void loadScript(const char *fname);
void loadSprite(const char *fname, int ref, int scene, V3D &pos);
void badLab(const char *fn);
- void caveUp(int cav);
- void switchCave(int cav);
+ void sceneUp(int cav);
+ void switchScene(int cav);
void showBak(int ref);
void loadTab();
int newRandom(int range);
@@ -229,7 +229,7 @@ public:
Text *_text;
HeroTab *_heroTab[2];
V3D *_eye;
- V3D *_eyeTab[kCaveMax];
+ V3D *_eyeTab[kSceneMax];
Spare *_spare;
CommandHandler *_commandHandler;
CommandHandler *_commandHandlerTurbo;
diff --git a/engines/cge2/cge2_main.cpp b/engines/cge2/cge2_main.cpp
index 198f4a359e..f4b90d3e2d 100644
--- a/engines/cge2/cge2_main.cpp
+++ b/engines/cge2/cge2_main.cpp
@@ -394,7 +394,7 @@ void CGE2Engine::movie(const char *ext) {
int now = _now;
_now = atoi(ext + 2);
loadScript(fn);
- caveUp(_now);
+ sceneUp(_now);
while (!_commandHandler->idle() && !_quitFlag)
mainLoop();
@@ -409,7 +409,7 @@ void CGE2Engine::movie(const char *ext) {
}
}
-void CGE2Engine::caveUp(int cav) {
+void CGE2Engine::sceneUp(int cav) {
_now = cav;
int bakRef = _now << 8;
if (_music)
@@ -418,7 +418,7 @@ void CGE2Engine::caveUp(int cav) {
*_eye = *(_eyeTab[_now]);
_mouseTop = V2D(this, V3D(0, 1, kScrDepth)).y;
_map->load(_now);
- _spare->takeCave(_now);
+ _spare->takeScene(_now);
openPocket();
for (int i = 0; i < 2; i++) {
@@ -459,8 +459,8 @@ void CGE2Engine::caveUp(int cav) {
//setDrawColors(); - It's only for debugging purposes. Can be left out for now.
}
-void CGE2Engine::switchCave(int cav) {
- warning("STUB: CGE2Engine::switchCave()");
+void CGE2Engine::switchScene(int cav) {
+ warning("STUB: CGE2Engine::switchScene()");
}
void CGE2Engine::showBak(int ref) {
@@ -575,7 +575,7 @@ void CGE2Engine::runGame() {
_infoLine->setText(nullptr);
_vga->_showQ->insert(_infoLine);
- caveUp(_now);
+ sceneUp(_now);
_startupMode = 0;
_mouse->center();
_mouse->off();
@@ -666,12 +666,12 @@ void CGE2Engine::loadGame() {
void CGE2Engine::loadPos() {
if (_resman->exist("CGE.HXY")) {
- for (int cav = 0; cav < kCaveMax; cav++)
+ for (int cav = 0; cav < kSceneMax; cav++)
_heroTab[1]->_posTab[cav] = new V2D(this, 180, 10);
EncryptedStream file(this, "CGE.HXY");
- for (int cav = 0; cav < kCaveMax; cav++) {
+ for (int cav = 0; cav < kSceneMax; cav++) {
_heroTab[0]->_posTab[cav]->x = file.readSint16LE();
_heroTab[0]->_posTab[cav]->y = file.readSint16LE();
}
@@ -708,14 +708,14 @@ void CGE2Engine::qGame() {
void CGE2Engine::loadTab() {
setEye(_text->getText(240));
- for (int i = 0; i < kCaveMax; i++)
+ for (int i = 0; i < kSceneMax; i++)
*(_eyeTab[i]) = *_eye;
if (_resman->exist(kTabName)) {
EncryptedStream f(this, kTabName);
uint32 v;
- for (int i = 0; i < kCaveMax; i++) {
+ for (int i = 0; i < kSceneMax; i++) {
v = f.readUint32LE();
_eyeTab[i]->_x = FXP(v >> 8, static_cast<int>((int8)(v & 0xff)));
@@ -860,7 +860,7 @@ void CGE2Engine::switchHero(int sex) {
if (scene >= 0) {
_commandHandler->addCommand(kCmdSeq, -1, 2, _heroTab[_sex]->_face);
_sex ^= 1;
- switchCave(scene);
+ switchScene(scene);
}
}
Sprite *face = _heroTab[_sex]->_face;
diff --git a/engines/cge2/hero.h b/engines/cge2/hero.h
index 69ee7b7810..628f7c1580 100644
--- a/engines/cge2/hero.h
+++ b/engines/cge2/hero.h
@@ -44,18 +44,18 @@ struct HeroTab {
Sprite *_face;
Sprite *_pocket[kPocketMax + 1];
int _pocPtr;
- V2D *_posTab[kCaveMax];
+ V2D *_posTab[kSceneMax];
HeroTab(CGE2Engine *vm) {
_ptr = nullptr;
_face = nullptr;
for (int i = 0; i < kPocketMax + 1; i++)
_pocket[i] = nullptr;
_pocPtr = 0;
- for (int i = 0; i < kCaveMax; i++)
+ for (int i = 0; i < kSceneMax; i++)
_posTab[i] = new V2D(vm);
}
~HeroTab() {
- for (int i = 0; i < kCaveMax; i++)
+ for (int i = 0; i < kSceneMax; i++)
delete _posTab[i];
}
};
diff --git a/engines/cge2/snail.cpp b/engines/cge2/snail.cpp
index 6b9ade6d58..5e417a1b8c 100644
--- a/engines/cge2/snail.cpp
+++ b/engines/cge2/snail.cpp
@@ -137,7 +137,7 @@ void CommandHandler::runCommand() {
warning("STUB: CommandHandler::runCommand() - Something missing connected to kCmdTime!");
break;
case kCmdCave:
- _vm->switchCave(tailCmd._val);
+ _vm->switchScene(tailCmd._val);
break;
case kCmdMidi:
_vm->snMidi(tailCmd._val);
@@ -381,9 +381,9 @@ void CGE2Engine::snSend(Sprite *spr, int val) {
if (!spr)
return;
// Sending", spr->File
// from cave", spr->Cave
// to cave", val
bool was1 = (_vga->_showQ->locate(spr->_ref) != nullptr);
bool val1 = (val == 0 || val == _now);
spr->_scene = val;
@@ -381,9 +381,9 @@ void CGE2Engine::snSend(Sprite *spr, int val) {
if (!spr)
return;
- // Sending", spr->File
- // from cave", spr->Cave
- // to cave", val
+ // Sending", spr->_file
+ // from scene", spr->_scene
+ // to scene", val
bool was1 = (_vga->_showQ->locate(spr->_ref) != nullptr);
bool val1 = (val == 0 || val == _now);